@@ -1,4 +1,6 @@
 from codecs import ignore_errors
+from .tools import try_ignore_exceptions
+import psycopg2
 import arrow
 import time
 import sys
@@ -484,30 +486,38 @@ def _restore_dump(
             docker_kill_container(container_id, remove=True)
             del container_id
 
-        try:
-            Commands.invoke(ctx, "down", volumes=True)
-        except Exception:
-            pass
+        Commands.invoke(ctx, "remove-volumes")
         Commands.invoke(ctx, "up", machines=["postgres"], daemon=True)
     Commands.invoke(ctx, "wait_for_container_postgres", missing_ok=True)
     conn = config.get_odoo_conn()
     dest_db = conn.dbname
 
     conn = conn.clone(dbname=DBNAME_RESTORING)
-    with config.forced() as config:
-        _dropdb(config, conn)
 
-    _execute_sql(
-        conn.clone(dbname="postgres"),
-        (
-            f"create database {DBNAME_RESTORING} "
-            # "ENCODING 'unicode' "
-            # "LC_COLLATE 'C' "
-            # "TEMPLATE template0 "
-            ";"
-        ),
-        notransaction=True,
+    def dropdb(config):
+        with config.forced() as config:
+            _dropdb(config, conn)
+        try_ignore_exceptions(
+            lambda: dropdb(config), (psycopg2.errors.AdminShutdown, psycopg2.InterfaceError), timeout=30
+        )
+
+    def create_db():
+        _execute_sql(
+            conn.clone(dbname="postgres"),
+            (
+                f"create database {DBNAME_RESTORING} "
+                # "ENCODING 'unicode' "
+                # "LC_COLLATE 'C' "
+                # "TEMPLATE template0 "
+                ";"
+            ),
+            notransaction=True,
+        )
+
+    try_ignore_exceptions(
+        create_db, (psycopg2.errors.AdminShutdown, psycopg2.InterfaceError), timeout=30
     )
+
     effective_host_name = config.DB_HOST
 
     if config.devmode and not no_dev_scripts:
