@@ -31,6 +31,7 @@ from .tools import __try_to_set_owner
 from .tools import whoami
 from .tools import abort
 from .tools import _get_version
+from .tools import rsync
 from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
 from .odoo_config import MANIFEST
@@ -305,6 +306,7 @@ def _do_compose(
     _prepare_yml_files_from_template_files(
         config, additional_docker_configuration_files
     )
+    _merge_odoo_dockerfile(config)
 
     click.echo("Built the docker-compose file.")
 
@@ -553,6 +555,7 @@ def _prepare_yml_files_from_template_files(
         _files2.append(x)
     _files = _files2
     del _files2
+
     _prepare_docker_compose_files(config, config.files["docker_compose"], _files)
 
 
@@ -581,7 +584,6 @@ def __get_sorted_contents(paths):
         # now probably not needed anymore
         content = path.read_text()
 
-        # dont matter if written manage-order: or manage-order
         if "manage-order" not in content:
             order = "99999999"
         else:
@@ -597,7 +599,7 @@ def __get_sorted_contents(paths):
 
 
 def __set_environment_in_services(content):
-    for service in (content.get("services", []) or []):
+    for service in content.get("services", []) or []:
         service = content["services"][service]
         service.setdefault("env_file", [])
         if isinstance(service["env_file"], str):
@@ -691,7 +693,16 @@ def __run_docker_compose_config(config, contents, env):
         except KeyError:
             d["DOCKER_GROUP_ID"] = "0"
 
-        conf = subprocess.check_output(cmdline, cwd=temp_path, env=d)
+        (temp_path / 'cmd').write_text(" ".join(map(str, cmdline)))
+        try:
+            conf = subprocess.check_output(cmdline, cwd=temp_path, env=d)
+        except:
+            for file in temp_path.glob("*"):
+                click.secho(f"{file}:\n", fg='yellow')
+                click.secho(file.read_text())
+            # get the output
+            conf = subprocess.check_output(cmdline, cwd=temp_path, env=d)
+            sys.exit(-1)
         conf = yaml.safe_load(conf)
         return conf
 
@@ -809,7 +820,7 @@ def _explode_referenced_machines(contents):
     needs_explosion = {}
 
     for content in contents:
-        for service in (content.get("services", []) or []):
+        for service in content.get("services", []) or []:
             labels = content["services"][service].get("labels")
             if labels:
                 if labels.get("compose.merge"):
@@ -927,9 +938,18 @@ def _use_file(config, path):
             run_key = "RUN_{}".format(path.parent.name).upper()
             return getattr(config, run_key)
 
-        if "run_odoo_version.{}.yml".format(config.odoo_version) in path.name:
+        if f"run_odoo_version.{config.odoo_version}.yml" in path.name:
             return True
 
+        customs_dir = config.customs_dir
+        try:
+            path.relative_to(customs_dir)
+        except ValueError:
+            pass
+        else:
+            if ".run_" not in path.name:
+                return True
+
         # requires general run:
         if getattr(config, "run_{}".format(path.parent.name)) or "run_" in path.name:
             run = list(
@@ -983,4 +1003,45 @@ def _apply_autorepo(ctx, config):
     _turn_into_odoosh(ctx, customs_dir())
 
 
+def _merge_odoo_dockerfile(config):
+    """
+    If customs contains dockerfile, then append their execution
+    in the main dockerfile
+    """
+    import yaml
+
+    content = config.files["docker_compose"].read_text()
+    content = yaml.safe_load(content)
+    dockerfile1 = None
+    for service in content["services"]:
+        service = content["services"][service]
+        dockerfile = service.get("build", {})
+        if isinstance(dockerfile, str):
+            continue
+        dockerfile = dockerfile.get("dockerfile")
+        if not dockerfile:
+            continue
+        if "odoo/images/odoo" in dockerfile:
+            shutil.copy(dockerfile, config.files["odoo_docker_file"])
+            dockerfile1 = dockerfile
+            service["build"]["dockerfile"] = str(config.files["odoo_docker_file"])
+        del dockerfile
+    content = yaml.dump(content, default_flow_style=False)
+    config.files["docker_compose"].write_text(content)
+
+    # copy dockerfile to new location
+    if dockerfile1:
+        click.secho(f"Copying {dockerfile1} to {config.files['odoo_docker_file']}")
+        config.files["odoo_docker_file"].write_text(Path(dockerfile1).read_text())
+        for file in bash_find(config.WORKING_DIR, "Dockerfile.appendix"):
+            appendix = file.read_text()
+            file = config.files["odoo_docker_file"]
+            content = file.read_text() + "\n" + appendix
+            content = content.replace("${PROJECT_NAME}", config.project_name)
+            file.write_text(content)
+    else:
+        # seems to use images from registry; no build section
+        pass
+
+
 Commands.register(do_reload, "reload")
