@@ -1,4 +1,7 @@
 import click
+from subprocess import Popen, PIPE
+
+import re
 import os
 from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
@@ -71,6 +74,44 @@ def do_kill(ctx, config, machines, brutal=False):
         lib_do_kill(ctx, config, machines, brutal=False)
 
 
+@docker.command()
+@click.option("-d", "--dry-run", is_flag=True)
+@pass_config
+@click.pass_context
+def remove_volumes(ctx, config, dry_run):
+    """
+    Experience: docker-compose down -v lets leftovers since june/2023
+    At restore everything must be cleaned up.
+    """
+    ensure_project_name(config)
+    if not config.devmode:
+        if not config.force:
+            abort("Please provide force option on non live systems")
+    if not config.use_docker:
+        return
+    subprocess.check_call(["sync"])
+    volumes = _get_project_volumes(config)
+    for vol in volumes:
+        click.secho(f"Removing: {vol}", fg="red")
+        if not dry_run:
+            rc = subprocess.run(
+                ["docker", "volume", "rm", "-f", vol], encoding="utf8",
+                capture_output=True,
+            )
+            if rc.returncode:
+                output = rc.stderr
+                for group in re.findall(r"(\[[^\]]*])", output):
+                    container_id = group[1:-1]
+                    subprocess.run(["docker", "kill", container_id])
+                    subprocess.check_call(["docker", "rm", "-fv", container_id])
+                    output = subprocess.check_output(
+                        ["docker", "volume", "rm", "-f", vol], encoding="utf8"
+                    )
+
+        if dry_run:
+            click.secho("Dry Run - didnt do it.")
+
+
 @docker.command()
 @pass_config
 @click.pass_context
@@ -307,6 +348,27 @@ def shell(config, command, queuejobs):
 #     lib_shell(command, queuejobs)
 
 
+def _get_project_volumes(config):
+    ensure_project_name(config)
+    import yaml
+
+    compose = yaml.safe_load(config.files["docker_compose"].read_text())
+    full_volume_names = []
+    for volume in compose["volumes"]:
+        full_volume_names.append(f"{config.project_name}_{volume}")
+    system_volumes = subprocess.check_output(
+        ["docker", "volume", "ls"], encoding="utf8"
+    ).splitlines()[1:]
+    system_volumes = [x.split(" ")[-1] for x in system_volumes]
+    system_volumes = [x for x in system_volumes if "_" in x]  # named volumes
+    system_volumes = [
+        x for x in system_volumes if x.startswith(config.project_name + "_")
+    ]
+
+    full_volume_names = list(filter(lambda x: x in system_volumes, full_volume_names))
+    return full_volume_names
+
+
 @docker.command()
 @click.option("-f", "--filter")
 @pass_config
@@ -315,25 +377,14 @@ def show_volumes(config, filter):
     from tabulate import tabulate
     from .lib_control_with_docker import _get_volume_size
 
-    volumes = (
-        subprocess.check_output(["docker", "volume", "ls"])
-        .decode("utf-8")
-        .split("\n")[1:]
-    )
-    volumes = [x.split(" ")[-1] for x in volumes]
-    volumes = [[x] for x in volumes if "_" in x]  # named volumes
-    volumes = [x for x in volumes if config.project_name in x[0]]
+    volumes = _get_project_volumes(config)
     if filter:
         volumes = [x for x in volumes if filter in x]
+    recs = []
     for volume in volumes:
-        size = _get_volume_size(volume[0])
-        volume.append(size)
-    click.echo(tabulate(volumes, ["Volume", "Size"]))
-
-    click.secho("\ndocker-compose file:", bold=True)
-    compose = yaml.safe_load(config.files["docker_compose"].read_text())
-    for volume in compose["volumes"]:
-        click.secho(f"docker-compose volume: {volume}")
+        size = _get_volume_size(volume)
+        recs.append((volume, size))
+    click.echo(tabulate(recs, ["Volume", "Size"]))
 
 
 @docker.command()
@@ -457,3 +508,4 @@ Commands.register(restart)
 Commands.register(shell, "odoo-shell")
 Commands.register(down)
 Commands.register(stop)
+Commands.register(remove_volumes, "remove-volumes")
