@@ -23,16 +23,23 @@ def talk(config):
 
 
 @talk.command()
+@click.argument("name", required=False)
 @click.option("-M", "--module")
 @click.option("-m", "--model")
 @pass_config
-def xmlids(config, module, model):
+def xmlids(config, name, module, model):
     conn = config.get_odoo_conn()
     where = " where 1 = 1"
     if model:
         where += f" AND model = '{model}'"
     if module:
         where += f" AND module = '{model}'"
+    if name:
+        where += (
+            f" and (model ilike '%{name}%' or "
+            f"name ilike '%{name}%' or "
+            f"module ilike '%{name}%')"
+        )
     rows = _execute_sql(
         conn,
         sql=(
@@ -174,13 +181,13 @@ def modules_overview(config):
         manifest = mod.manifest_dict
 
         combined_description = []
-        for field in ['summary', 'description']:
+        for field in ["summary", "description"]:
             combined_description.append(manifest.get(field, ""))
         for readme in ["README.md", "README.rst", "README.txt"]:
             readmefile = mod.path / readme
             if readmefile.exists():
                 combined_description.append(readmefile.read_text())
-        description = '\n'.join(filter(bool, combined_description))
+        description = "\n".join(filter(bool, combined_description))
         data = {
             "name": mod.name,
             "path": str(mod.path),
@@ -300,4 +307,59 @@ def groups(config, name):
     )
 
 
+@talk.command()
+@click.argument("login", required=False, default="%")
+@pass_config
+def users(config, login):
+    conn = config.get_odoo_conn()
+    rows = _execute_sql(
+        conn,
+        sql=(
+            f"SELECT login, name FROM res_users INNER JOIN "
+            f"res_partner p on p.id = res_users.partner_id "
+            f"WHERE p.name ILIKE '%{login}%' or login ILIKE '%{login}%'"
+        ),
+        fetchall=True,
+        return_columns=False,
+    )
+
+    cols = ["login", "name"]
+    click.secho(
+        tabulate(rows, cols, tablefmt="fancy_grid"),
+        fg="yellow",
+    )
+
+
+@talk.command()
+@click.argument("model", required=False, default="%")
+@click.argument("field", required=False, default="%")
+@pass_config
+def fields(config, model, field):
+    conn = config.get_odoo_conn()
+    sql = (
+        "SELECT f.name, f.ttype "
+        "FROM ir_model_fields f INNER JOIN "
+        "ir_model m ON "
+        "f.model_id = m.id "
+        "WHERE 1=1 "
+    )
+    if model:
+        sql += f" AND m.model ilike '%{model}%' "
+    if field:
+        sql += f" AND f.name ilike '%{field}%' "
+
+    rows = _execute_sql(
+        conn,
+        sql=sql,
+        fetchall=True,
+        return_columns=False,
+    )
+
+    cols = ["name", "ttype"]
+    click.secho(
+        tabulate(rows, cols, tablefmt="fancy_grid"),
+        fg="yellow",
+    )
+
+
 Commands.register(progress)
