@@ -15,7 +15,9 @@ from .tools import __try_to_set_owner as try_to_set_owner
 from .tools import measure_time
 from .tools import is_git_clean
 from .tools import whoami
+from .tools import abort
 from .tools import __rmtree as rmtree
+from .tools import pretty_xml
 
 try:
     from psycopg2 import IntegrityError
@@ -146,8 +148,11 @@ def get_all_langs(config):
     return langs
 
 
-def get_modules_from_install_file():
-    return MANIFEST().get("install", [])
+def get_modules_from_install_file(include_uninstall):
+    res = MANIFEST().get("install", [])
+    if include_uninstall:
+        res += MANIFEST().get("uninstall", [])
+    return res
 
 
 class DBModules(object):
@@ -594,37 +599,39 @@ def update_view_in_db(filepath, lineno):
                     )
                     view_type, view_name = cr.fetchone()
 
-                    if view_type == "qweb":
-                        cr.execute(
-                            "select id from ir_ui_view where type ='qweb' and name = %s",
-                            (view_name,),
-                        )
-                        view_ids = set(cr.fetchall())
-
-                    cr.execute(
-                        "update ir_ui_view set {}=%s where id in %s".format(
-                            arch_column
-                        ),
-                        [arch, tuple(view_ids)],
-                    )
-                    cr.connection.commit()
-                    if arch_fs_column:
-                        try:
-                            rel_path = (
-                                module.name
-                                + "/"
-                                + str(filepath.relative_to(module.path))
-                            )
+                    version = current_version()
+                    if version <= 15.0:
+                        if view_type == "qweb":
                             cr.execute(
-                                "update ir_ui_view set arch_fs=%s where id in %s",
-                                [
-                                    rel_path,
-                                    tuple(view_ids),
-                                ],
+                                "select id from ir_ui_view where type ='qweb' and name = %s",
+                                (view_name,),
                             )
-                            cr.connection.commit()
-                        except Exception:
-                            cr.connection.rollback()
+                            view_ids = set(cr.fetchall())
+
+                        cr.execute(
+                            "update ir_ui_view set {}=%s where id in %s".format(
+                                arch_column
+                            ),
+                            [arch, tuple(view_ids)],
+                        )
+                        cr.connection.commit()
+                        if arch_fs_column:
+                            try:
+                                rel_path = (
+                                    module.name
+                                    + "/"
+                                    + str(filepath.relative_to(module.path))
+                                )
+                                cr.execute(
+                                    "update ir_ui_view set arch_fs=%s where id in %s",
+                                    [
+                                        rel_path,
+                                        tuple(view_ids),
+                                    ],
+                                )
+                                cr.connection.commit()
+                            except Exception:
+                                cr.connection.rollback()
 
                     if res:
                         exe("ir.ui.view", "write", view_ids, {"arch_db": arch})
@@ -705,7 +712,7 @@ class Modules(object):
                 modules.append(module.name)
 
     # @profile
-    def get_customs_modules(self, mode=None):
+    def get_customs_modules(self, mode=None, include_uninstall=False):
         """
         Called by odoo update
 
@@ -717,7 +724,7 @@ class Modules(object):
         """
         assert mode in [None, "to_update", "to_install"]
 
-        modules = get_modules_from_install_file()
+        modules = get_modules_from_install_file(include_uninstall=include_uninstall)
 
         if mode == "to_install":
             modules = [x for x in modules if not DBModules.is_module_installed(x)]
@@ -761,8 +768,8 @@ class Modules(object):
                                 f"Module not found at resolving dependencies: {dep}"
                                 ". Not necessarily a problem at auto install modules."
                             ),
-                            fg="yellow",
-                            bold=True,
+                            fg="blue",
+                            bold=False,
                         )
                     dep_mod = Module(None, force_name=dep)
 
@@ -867,13 +874,13 @@ class Modules(object):
         return list(sorted(set(modules)))
 
     # @profile
-    def get_all_used_modules(self):
+    def get_all_used_modules(self, include_uninstall=False):
         """
         Returns all modules that are directly or indirectly
         (auto install, depends) installed.
         """
         result = set()
-        modules = self.get_customs_modules()
+        modules = self.get_customs_modules(include_uninstall=True)
         auto_install_modules = (
             self.get_filtered_auto_install_modules_based_on_module_list(modules)
         )
@@ -894,7 +901,6 @@ class Modules(object):
             if module.path is None:
                 raise Exception(f"Module has no path: {module_name}")
             file = module.path / "external_dependencies.txt"
-            new_deps = []
 
             def extract_deps(data):
                 global_data["pip"].extend(data.get("pip", data.get("python", [])))
@@ -923,7 +929,15 @@ class Modules(object):
 
         # keep highest version and or leaveout loosers
         def _map(x):
-            arr = iscompatible.parse_requirements(x)
+            if x:
+                try:
+                    arr = iscompatible.parse_requirements(x)
+                except:
+                    import pudb
+
+                    pudb.set_trace()
+            else:
+                arr = []
             for arr in arr:
                 if arr:
                     arr = list(arr)
@@ -933,11 +947,15 @@ class Modules(object):
         parsed_requirements = []
         for inst in pydeps:
             libname = _extract_python_libname(inst)
-            for parsed in [
-                _map(x) for x in pydeps if _extract_python_libname(x) == libname
-            ]:
-                for x in parsed:
-                    parsed_requirements.append((libname, x))
+            if "@" in inst:
+                # concrete url like "pymssql@git+https://github.com/marcwimmer/pymssql"
+                parsed_requirements.append(inst)
+            else:
+                for parsed in [
+                    _map(x) for x in pydeps if _extract_python_libname(x) == libname
+                ]:
+                    for x in parsed:
+                        parsed_requirements.append((libname, x))
         """
         parsed_requirements ilike
         [
@@ -947,7 +965,11 @@ class Modules(object):
         """
 
         allowed = ["==", ">="]
-        unallowed = [x for x in parsed_requirements if x[1][0] not in allowed]
+        unallowed = [
+            x
+            for x in parsed_requirements
+            if not isinstance(x, str) and x[1][0] not in allowed
+        ]
         if unallowed:
             raise Exception(f"Unhandled: {unallowed} - only {allowed} allowed")
 
@@ -1095,6 +1117,8 @@ class Module(object):
     def manifest_dict(self):
         if not self._manifest_dict:
             try:
+                if not self.manifest_path:
+                    abort(f"Could not find manifest path for {self.name}")
                 path = customs_dir() / self.manifest_path
                 content = path.read_text()
                 content = "\n".join(
@@ -1105,10 +1129,7 @@ class Module(object):
                 self._manifest_dict = eval(content)  # TODO safe
 
             except (SyntaxError, Exception) as e:
-                click.secho(
-                    (f"error at file: {self.manifest_path}:\n{str(e)}"), fg="red"
-                )
-                sys.exit(-1)
+                abort((f"error at file: {self.manifest_path}:\n{str(e)}"), fg="red")
         return self._manifest_dict
 
     def __make_path_relative(self, path):
@@ -1250,7 +1271,7 @@ class Module(object):
         filepath = self.path / "views/assets.xml"
         current_id = None
         if filepath.exists():
-            with filepath.open("r") as f:
+            with filepath.open("rb") as f:
                 xml = f.read()
                 doc = etree.XML(xml)
                 for t in doc.xpath("//template/@inherit_id"):
@@ -1337,15 +1358,14 @@ class Module(object):
                         if file not in jsoncontent["assets"][asset_name]:
                             jsoncontent["assets"][asset_name].append(file)
                         del file
-            manifest.write_text(pprint.pformat(jsoncontent))
+            self.write_manifest(jsoncontent)
         else:
             if not doc.xpath("//link| //script"):
                 if filepath.exists():
                     filepath.unlink()
             else:
                 filepath.parent.mkdir(exist_ok=True)
-                with filepath.open("wb") as f:
-                    f.write(etree.tostring(doc, pretty_print=True))
+                filepath.write_bytes(pretty_xml(etree.tostring(doc, pretty_print=True)))
 
     def get_all_files_of_module(self):
         for file in self.path.glob("**/*"):
@@ -1494,7 +1514,9 @@ class Module(object):
 
         # remove assets.xml for newer versions
         if current_version() > 14.0:
-            mod[DATA_NAME] = list(filter(lambda x: not x.endswith("/assets.xml"), mod[DATA_NAME]))
+            mod[DATA_NAME] = list(
+                filter(lambda x: not x.endswith("/assets.xml"), mod[DATA_NAME])
+            )
 
         if is_web:
             mod["web"] = True
@@ -1504,9 +1526,11 @@ class Module(object):
         self.write_manifest(mod)
 
     def write_manifest(self, data):
-        with self.manifest_path.open("w") as file:
-            pp = pprint.PrettyPrinter(indent=4, stream=file)
-            pp.pprint(data)
+        from black import format_str, FileMode
+
+        data = str(data)
+        data = format_str(data, mode=FileMode())
+        self.manifest_path.write_text(data)
 
     def calc_complexity(self):
         """
