@@ -1,4 +1,5 @@
 import uuid
+import time
 from subprocess import PIPE, STDOUT
 import hashlib
 import requests
@@ -306,19 +307,19 @@ def _wait_postgres(config, timeout=600):
                 raise Exception(f"Timeout waiting postgres reached: {timeout}seconds")
             try:
                 _execute_sql(
-                    conn,
-                    sql="""
-                SELECT table_schema,table_name
-                FROM information_schema.tables
-                ORDER BY table_schema,table_name
-                LIMIT 1;
-                """,
+                    conn.clone(dbname="postgres"),
+                    sql=(
+                        " SELECT table_schema,table_name "
+                        " FROM information_schema.tables "
+                        " ORDER BY table_schema,table_name "
+                        " LIMIT 1; "
+                    ),
                 )
                 break
 
             except Exception as ex:
                 seconds = (arrow.get() - started).total_seconds()
-                if seconds > 5:
+                if seconds > 10:
                     if str(ex) != str(last_ex):
                         click.secho(
                             f"Waiting again for postgres. Last error is: {str(ex)}"
@@ -561,7 +562,8 @@ def __rmtree(config, path):
         raise Exception("Not allowed: {}".format(path))
     if config:
         if not any(
-            path.startswith(config.dirs["odoo_home"] + x) for x in ["/tmp", "/run/"]
+            path.startswith(str(config.dirs["odoo_home"]) + x)
+            for x in ["/tmp", "/run/"]
         ):
             if "/tmp" in path:
                 pass
@@ -968,8 +970,10 @@ def rsync(src, dest, options="-ar", exclude=None):
     exclude_option = []
     for x in exclude:
         exclude_option += ["--exclude", x]
+    if not isinstance(options, list):
+        options = [options]
     subprocess.check_call(
-        ["rsync", str(src) + "/", str(dest) + "/", options] + exclude_option
+        ["rsync", str(src) + "/", str(dest) + "/"] + options + exclude_option
     )
 
 
@@ -996,7 +1000,6 @@ def _get_host_ip():
         return conn[2]
 
 
-
 def __assure_gitignore(gitignore_file, content):
     p = Path(gitignore_file)
     if not p.exists():
@@ -1048,6 +1051,9 @@ def measure_time(method):
 
 
 def _extract_python_libname(x):
+    if "@" in x:
+        # return vcs refs
+        return x
     regex = re.compile(r"[\w\-\_]*")
     x = x.replace("-", "_")
     match = re.findall(regex, x)[0]
@@ -1179,6 +1185,22 @@ def _binary_zip(folder, destpath):
         raise Exception(f"file {destpath} not generated")
 
 
+def try_ignore_exceptions(execute, exceptions, timeout=10):
+    started = arrow.get()
+    while True:
+        try:
+            execute()
+        except exceptions:
+            if (arrow.get() - started).total_seconds() > timeout:
+                raise
+            else:
+                time.sleep(0.5)
+        except Exception:
+            raise
+        else:
+            break
+
+
 @contextmanager
 def autocleanpaper(filepath=None, strict=False):
     if strict:
@@ -1486,10 +1508,19 @@ def cwd(path):
 @contextmanager
 def atomic_write(file):
     tempfile = file.parent / f"{file.name}.{uuid.uuid4()}"
-    yield tempfile
-    if file.exists():
-        file.unlink()
-    tempfile.rename(file)
+    try:
+        yield tempfile
+
+        if file.exists():
+            file.unlink()
+        tempfile.rename(file)
+
+    except Exception:
+        if tempfile.exists():
+            try:
+                tempfile.unlink()
+            except Exception:
+                pass
 
 
 def bash_find(path, name=None, wholename=None, type=None):
@@ -1507,3 +1538,15 @@ def bash_find(path, name=None, wholename=None, type=None):
         cmd += ["-name", name]
     files = subprocess.check_output(cmd, cwd=path, encoding="utf8").splitlines()
     return list(map(lambda x: Path(path) / x, files))
+
+
+def pretty_xml(xmlstring):
+    with autocleanpaper() as tempfile:
+        tempfile.write_bytes(xmlstring)
+        formatted = subprocess.check_output(
+            ["xmllint", "--format", tempfile],
+            env={
+                "XMLLINT_INDENT": "    ",
+            },
+        )
+        return formatted
